
sncosmo.StretchModel
====================

.. currentmodule:: sncosmo

.. autoclass:: StretchModel
   :show-inheritance:

   
   
   .. rubric:: Attributes

   .. autosummary::
   
         cosmo
         params
         parnames
         refband
         refmagsys
         refphase
   
   


   
   
   .. rubric:: Methods Summary

   .. autosummary::
   
      ~StretchModel.__call__
      ~StretchModel.bandflux
      ~StretchModel.bandmag
      ~StretchModel.bandoverlap
      ~StretchModel.disp
      ~StretchModel.flux
      ~StretchModel.set
      ~StretchModel.set_bandflux_relative_error
      ~StretchModel.set_extinction_func
      ~StretchModel.times
   
   


   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: __call__
   .. automethod:: bandflux
   .. automethod:: bandmag
   .. automethod:: bandoverlap
   .. automethod:: disp
   .. automethod:: flux
   .. automethod:: set
   .. automethod:: set_bandflux_relative_error
   .. automethod:: set_extinction_func
   .. automethod:: times

   
   